@@ -4,9 +4,9 @@ use strict;
 use Acme::CPANModulesUtil::Misc;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-11-17'; # DATE
+our $DATE = '2024-01-18'; # DATE
 our $DIST = 'Acme-CPANModules-GrepVariants'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 my $description = <<'_';
 This list catalogs various grep-like tools.
@@ -84,14 +84,20 @@ multiple terms into a chain of look-ahead patterns like described above. This
 allows you to use the standard grep.
 
 
-**3. Variants: alternate ways of specifying regex**
+**3. Variants: alternate ways of specifying things to search for**
 
-Instead of specifying a pattern, with <prog:rpgrep> (from <pm:App::rpgrep>) you
-can specify a pattern name in a <pm:Regexp::Pattern>::* module instead.
+Instead of specifying a regexp pattern directly, with <prog:rpgrep> (from
+<pm:App::rpgrep>) you can specify a pattern name in a <pm:Regexp::Pattern>::*
+module instead.
 
 With <prog:wcgrep> (from <pm:App::wcgrep>) you can search using wildcard pattern
 instead of regex, which is admittedly more limited than regex.
 
+<prog:grep-similar-text> (from <pm:App::grep::similar::text> lets you specify a
+text and it will only show lines from input that are similar to the provided
+text.
+
+
 **4a. Variants: alternate source: repository (version control system) content and history**
 
 For git, the abovementioned `git-grep` can search for files in the work tree as
@@ -99,6 +105,7 @@ well as commit content. For Mercurial, `hg grep` accomplishes the same.
 Alternatively you can dump the history then use the standard `grep` to go
 through it.
 
+
 **4b. Variants: alternate source: Perl source code**
 
 <prog:pmgrep> (from <pm:App::pmgrep>) lets you grep over locally installed Perl
@@ -118,7 +125,7 @@ or inside string literals.
 <prog:podgrep> (from <pm:pmtools>) greps from POD sections of Perl source.
 
 
-**4b. Variants: alternate source: CSV**
+**4c. Variants: alternate source: CSV**
 
 <prog:csvgrep> (from <pm:csvgrep>)
 
@@ -126,13 +133,13 @@ or inside string literals.
 rows of CSV.
 
 
-**4c. Variants: alternate source: word lists**
+**4d. Variants: alternate source: word lists**
 
 <prog:wordlist> (from <pm:App::wordlist>) greps words from wordlist modules
 (modules that contains word lists, see WordList).
 
 
-**4d. Variants: other alternate sources**
+**4e. Variants: other alternate sources**
 
 <prog:grep-from-bash-history> (from <pm:App::BashHistoryUtils>).
 
@@ -193,7 +200,7 @@ Acme::CPANModules::GrepVariants - List of grep-like CLI utilities available on C
 
 =head1 VERSION
 
-This document describes version 0.011 of Acme::CPANModules::GrepVariants (from Perl distribution Acme-CPANModules-GrepVariants), released on 2023-11-17.
+This document describes version 0.012 of Acme::CPANModules::GrepVariants (from Perl distribution Acme-CPANModules-GrepVariants), released on 2024-01-18.
 
 =head1 DESCRIPTION
 
@@ -269,14 +276,19 @@ L<grep-terms> (from L<App::GrepUtils>) is a grep wrapper to convert
 multiple terms into a chain of look-ahead patterns like described above. This
 allows you to use the standard grep.
 
-B<3. Variants: alternate ways of specifying regex>
+B<3. Variants: alternate ways of specifying things to search for>
 
-Instead of specifying a pattern, with L<rpgrep> (from L<App::rpgrep>) you
-can specify a pattern name in a L<Regexp::Pattern>::* module instead.
+Instead of specifying a regexp pattern directly, with L<rpgrep> (from
+L<App::rpgrep>) you can specify a pattern name in a L<Regexp::Pattern>::*
+module instead.
 
 With L<wcgrep> (from L<App::wcgrep>) you can search using wildcard pattern
 instead of regex, which is admittedly more limited than regex.
 
+L<grep-similar-text> (from L<App::grep::similar::text> lets you specify a
+text and it will only show lines from input that are similar to the provided
+text.
+
 B<4a. Variants: alternate source: repository (version control system) content and history>
 
 For git, the abovementioned C<git-grep> can search for files in the work tree as
@@ -302,19 +314,19 @@ or inside string literals.
 
 L<podgrep> (from L<pmtools>) greps from POD sections of Perl source.
 
-B<4b. Variants: alternate source: CSV>
+B<4c. Variants: alternate source: CSV>
 
 L<csvgrep> (from L<csvgrep>)
 
 L<csv-grep> (from L<App::CSVUtils>) allows you to apply Perl code against
 rows of CSV.
 
-B<4c. Variants: alternate source: word lists>
+B<4d. Variants: alternate source: word lists>
 
 L<wordlist> (from L<App::wordlist>) greps words from wordlist modules
 (modules that contains word lists, see WordList).
 
-B<4d. Variants: other alternate sources>
+B<4e. Variants: other alternate sources>
 
 L<grep-from-bash-history> (from L<App::BashHistoryUtils>).
 
@@ -383,6 +395,10 @@ Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
 =item L<App::wcgrep>
 
+Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
+
+=item L<App::grep::similar::text>
+
 =item L<App::pmgrep>
 
 Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
@@ -524,7 +540,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2021, 2020 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2024, 2023, 2021, 2020 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
